LabeledPolynomial

Struct LabeledPolynomial 

pub struct LabeledPolynomial<F: Field, P: Polynomial<F>> { /* private fields */ }
A polynomial along with information about its degree bound (if any), and the maximum number of queries that will be made to it. This latter number determines the amount of protection that will be provided to a commitment for this polynomial.

Implementations

Source

impl<'a, F: Field, P: Polynomial<F>> LabeledPolynomial<F, P>

pub fn new( label: PolynomialLabel, polynomial: P, degree_bound: Option<usize>, hiding_bound: Option<usize>, ) -> Self

Construct a new labeled polynomial.

pub fn label(&self) -> &String

Return the label for self.

pub fn polynomial(&self) -> &P

Retrieve an immutable reference to the polynomial contained in self.

pub fn polynomial_mut(&mut self) -> &mut P

Retrieve a mutable reference to the polynomial contained in self

pub fn evaluate(&self, point: &P::Point) -> F

Evaluate the polynomial in self.

pub fn degree(&self) -> usize

Retrieve the degree of the polynomial in self.

pub fn degree_bound(&self) -> Option<usize>

Retrieve the degree bound in self.

pub fn is_hiding(&self) -> bool

Retrieve whether the polynomial in self should be hidden.

pub fn hiding_bound(&self) -> Option<usize>

Retrieve the hiding bound for the polynomial in self.