pub trait PCCommitterKey:
Clone
+ Debug
+ CanonicalSerialize
+ CanonicalDeserialize {
// Required methods
fn max_degree(&self) -> usize;
fn supported_degree(&self) -> usize;
}Expand description
Defines the minimal interface of committer keys for any polynomial commitment scheme.
Required Methods
Sourcefn max_degree(&self) -> usize
fn max_degree(&self) -> usize
Outputs the maximum degree supported by the universal parameters
Self was derived from.
Sourcefn supported_degree(&self) -> usize
fn supported_degree(&self) -> usize
Outputs the maximum degree supported by the committer key.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".