pub trait PCUniversalParams:
Clone
+ Debug
+ CanonicalSerialize
+ CanonicalDeserialize {
// Required method
fn max_degree(&self) -> usize;
}Expand description
Defines the minimal interface for public params for any polynomial commitment scheme.
Required Methods
Sourcefn max_degree(&self) -> usize
fn max_degree(&self) -> usize
Outputs the maximum degree supported by the committer key.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".