pub struct HyraxCommitment<G: AffineRepr> {
pub row_coms: Vec<G>,
}Expand description
Hyrax commitment to a polynomial consisting of one multi-commit per row of the coefficient matrix
Fields
row_coms: Vec<G>A list of multi-commits to each row of the matrix representing the polynomial.