pub struct HyraxProof<G: AffineRepr> {
pub com_eval: G,
pub com_d: G,
pub com_b: G,
pub z: Vec<G::ScalarField>,
pub z_d: G::ScalarField,
pub z_b: G::ScalarField,
}Expand description
Proof of a Hyrax opening, containing various commitments and auxiliary values generated randomly during the opening
Fields
com_eval: GCommitment to the evaluation of the polynomial at the requested point
com_d: GCommitment to auxiliary random vector d
com_b: GCommitment to auxiliary random scalar b
z: Vec<G::ScalarField>Auxiliary random vector
z_d: G::ScalarFieldAuxiliary random scalar
z_b: G::ScalarFieldAuxiliary random scalar