pub struct Commitment<G: AffineRepr> {
pub comm: G,
pub shifted_comm: Option<G>,
}Expand description
Commitment to a polynomial that optionally enforces a degree bound.
Fields
comm: GA Pedersen commitment to the polynomial.
shifted_comm: Option<G>A Pedersen commitment to the shifted polynomial.
This is none if the committed polynomial does not
enforce a strict degree bound.