pub struct CommitterKey<G: AffineRepr> {
pub comm_key: Vec<G>,
pub h: G,
pub s: G,
pub max_degree: usize,
}Expand description
CommitterKey is used to commit to, and create evaluation proofs for, a given
polynomial.
Fields
comm_key: Vec<G>The key used to commit to polynomials.
h: GA random group generator.
s: GA random group generator that is to be used to make a commitment hiding.
max_degree: usizeThe maximum degree supported by the parameters this key was derived from.