pub struct Proof<G: AffineRepr> {
pub l_vec: Vec<G>,
pub r_vec: Vec<G>,
pub final_comm_key: G,
pub c: G::ScalarField,
pub hiding_comm: Option<G>,
pub rand: Option<G::ScalarField>,
}Expand description
Proof is an evaluation proof that is output by InnerProductArg::open.
Fields
l_vec: Vec<G>Vector of left elements for each of the log_d iterations in open
r_vec: Vec<G>Vector of right elements for each of the log_d iterations within open
final_comm_key: GCommitter key from the last iteration within open
c: G::ScalarFieldCoefficient from the last iteration within withinopen`
hiding_comm: Option<G>Commitment to the blinding polynomial.
rand: Option<G::ScalarField>Linear combination of all the randomness used for commitments to the opened polynomials, along with the randomness used for the commitment to the hiding polynomial.