Randomness

Struct Randomness 

pub struct Randomness<G: AffineRepr> {
    pub rand: G::ScalarField,
    pub shifted_rand: Option<G::ScalarField>,
}
Randomness hides the polynomial inside a commitment and is outputted by InnerProductArg::commit.

Fields

rand: G::ScalarField

Randomness is some scalar field element.

shifted_rand: Option<G::ScalarField>

Randomness applied to the shifted commitment is some scalar field element.