pub struct VerifierKey<E: Pairing> {
pub vk: VerifierKey<E>,
pub degree_bounds_and_shift_powers: Option<Vec<(usize, E::G1Affine)>>,
pub max_degree: usize,
pub supported_degree: usize,
}Expand description
VerifierKey is used to check evaluation proofs for a given commitment.
Fields
vk: VerifierKey<E>The verification key for the underlying KZG10 scheme.
degree_bounds_and_shift_powers: Option<Vec<(usize, E::G1Affine)>>Information required to enforce degree bounds. Each pair
is of the form (degree_bound, shifting_advice).
The vector is sorted in ascending order of degree_bound.
This is None if self does not support enforcing any degree bounds.
max_degree: usizeThe maximum degree supported by the UniversalParams self was derived
from.
supported_degree: usizeThe maximum degree supported by the trimmed parameters that self is
a part of.
Implementations
Sourceimpl<E: Pairing> VerifierKey<E>
impl<E: Pairing> VerifierKey<E>
Sourcepub fn get_shift_power(&self, bound: usize) -> Option<E::G1Affine>
pub fn get_shift_power(&self, bound: usize) -> Option<E::G1Affine>
Find the appropriate shift for the degree bound.