Module marlin_pst13_pc

Module marlin_pst13_pc 

Multivariate polynomial commitment based on the construction in [PST13] with batching and (optional) hiding property inspired by the univariate scheme in [CHMMVW20, “Marlin”]

Structs

CommitterKey
CommitterKey is used to commit to and create evaluation proofs for a given polynomial.
MarlinPST13
Multivariate polynomial commitment based on the construction in [PST13] with batching and (optional) hiding property inspired by the univariate scheme in [CHMMVW20, “Marlin”]
Proof
Proof is an evaluation proof that is output by KZG10::open.
Randomness
Randomness hides the polynomial inside a commitment`.
UniversalParams
UniversalParams are the universal parameters for the MarlinPST13 scheme.
VerifierKey
VerifierKey is used to check evaluation proofs for a given commitment.

Type Aliases

PreparedVerifierKey
Nothing to do to prepare this verifier key (for now).