pub struct MarlinPST13<E: Pairing, P: DenseMVPolynomial<E::ScalarField>> { /* private fields */ }Expand description
Multivariate polynomial commitment based on the construction in [PST13] with batching and (optional) hiding property inspired by the univariate scheme in [CHMMVW20, “Marlin”]