pub struct Proof<E: Pairing> {
pub w: Vec<E::G1Affine>,
pub random_v: Option<E::ScalarField>,
}Expand description
Proof is an evaluation proof that is output by KZG10::open.
Fields
w: Vec<E::G1Affine>Commitments to the witness polynomials
random_v: Option<E::ScalarField>Evaluation of the random polynomial at the point for which the evaluation proof was produced.