pub struct VerifierKey<E: Pairing> {
pub g: E::G1Affine,
pub gamma_g: E::G1Affine,
pub h: E::G2Affine,
pub beta_h: Vec<E::G2Affine>,
pub prepared_h: E::G2Prepared,
pub prepared_beta_h: Vec<E::G2Prepared>,
pub num_vars: usize,
pub supported_degree: usize,
pub max_degree: usize,
}Expand description
VerifierKey is used to check evaluation proofs for a given commitment.
Fields
g: E::G1AffineThe generator of G1.
gamma_g: E::G1AffineThe generator of G1 that is used for making a commitment hiding.
h: E::G2AffineThe generator of G2.
beta_h: Vec<E::G2Affine>\beta_i times the above generator of G2 where i ranges from 0 to num_vars-1
prepared_h: E::G2PreparedThe generator of G2, prepared for use in pairings.
prepared_beta_h: Vec<E::G2Prepared>\beta_i times the above generator of G2 where i ranges from 0 to num_vars-1,
prepared for use in pairings
num_vars: usizeThe number of variables self is initialized for
supported_degree: usizeThe maximum degree supported by the trimmed parameters that self is
a part of.
max_degree: usizeThe maximum degree supported by the UniversalParams self was derived
from.