pub struct VerifierKey<E: Pairing> {
pub g: E::G1Affine,
pub gamma_g: E::G1Affine,
pub h: E::G2Affine,
pub beta_h: E::G2Affine,
pub prepared_h: E::G2Prepared,
pub prepared_beta_h: E::G2Prepared,
pub degree_bounds_and_neg_powers_of_h: Option<Vec<(usize, E::G2Affine)>>,
pub supported_degree: usize,
pub max_degree: usize,
}Expand description
VerifierKey is used to check evaluation proofs for a given commitment.
Fields
g: E::G1AffineThe generator of G1.
gamma_g: E::G1AffineThe generator of G1 that is used for making a commitment hiding.
h: E::G2AffineThe generator of G2.
beta_h: E::G2Affine\beta times the generator of G2.
prepared_h: E::G2PreparedThe generator of G2, prepared for use in pairings.
prepared_beta_h: E::G2PreparedThe \beta times the generator of G2, prepared for use in pairings.
degree_bounds_and_neg_powers_of_h: Option<Vec<(usize, E::G2Affine)>>Pairs a degree_bound with its corresponding G2 element, which has been prepared for use in pairings.
Each pair is in the form (degree_bound, \beta^{degree_bound - max_degree} h), where h is the generator of G2 above
supported_degree: usizeThe maximum degree supported by the trimmed parameters that self is
a part of.
max_degree: usizeThe maximum degree supported by the UniversalParams self was derived
from.
Implementations
Sourceimpl<E: Pairing> VerifierKey<E>
impl<E: Pairing> VerifierKey<E>
Sourcepub fn get_shift_power(&self, degree_bound: usize) -> Option<E::G2Prepared>
pub fn get_shift_power(&self, degree_bound: usize) -> Option<E::G2Prepared>
Find the appropriate shift for the degree bound.