pub struct LabeledPolynomial<F: Field, P: Polynomial<F>> { /* private fields */ }Expand description
A polynomial along with information about its degree bound (if any), and the maximum number of queries that will be made to it. This latter number determines the amount of protection that will be provided to a commitment for this polynomial.
Implementations
Sourceimpl<'a, F: Field, P: Polynomial<F>> LabeledPolynomial<F, P>
impl<'a, F: Field, P: Polynomial<F>> LabeledPolynomial<F, P>
Sourcepub fn new(
label: PolynomialLabel,
polynomial: P,
degree_bound: Option<usize>,
hiding_bound: Option<usize>,
) -> Self
pub fn new( label: PolynomialLabel, polynomial: P, degree_bound: Option<usize>, hiding_bound: Option<usize>, ) -> Self
Construct a new labeled polynomial.
Sourcepub fn polynomial(&self) -> &P
pub fn polynomial(&self) -> &P
Retrieve an immutable reference to the polynomial contained in self.
Sourcepub fn polynomial_mut(&mut self) -> &mut P
pub fn polynomial_mut(&mut self) -> &mut P
Retrieve a mutable reference to the polynomial contained in self
Sourcepub fn degree_bound(&self) -> Option<usize>
pub fn degree_bound(&self) -> Option<usize>
Retrieve the degree bound in self.
Sourcepub fn hiding_bound(&self) -> Option<usize>
pub fn hiding_bound(&self) -> Option<usize>
Retrieve the hiding bound for the polynomial in self.