Struct ark_poly_commit::marlin::marlin_pc::MarlinKZG10 [−][src]
pub struct MarlinKZG10<E: PairingEngine, P: UVPolynomial<E::Fr>> { /* fields omitted */ }
Polynomial commitment based on [KZG10], with degree enforcement, batching, and (optional) hiding property taken from [CHMMVW20, “Marlin”].
Degree bound enforcement requires that (at least one of) the points at which a committed polynomial is evaluated are from a distribution that is random conditioned on the polynomial. This is because degree bound enforcement relies on checking a polynomial identity at this point. More formally, the points must be sampled from an admissible query sampler, as detailed in [CHMMVW20].