Multivariate polynomial commitment based on the construction in [PST13] with batching and (optional) hiding property inspired by the univariate scheme in [CHMMVW20, “Marlin”]
Structs
- Committer
Key CommitterKeyis used to commit to and create evaluation proofs for a given polynomial.- MarlinPS
T13 - Multivariate polynomial commitment based on the construction in [PST13] with batching and (optional) hiding property inspired by the univariate scheme in [CHMMVW20, “Marlin”]
- Proof
Proofis an evaluation proof that is output byKZG10::open.- Randomness
Randomnesshides the polynomial inside a commitment`.- Universal
Params UniversalParamsare the universal parameters for the MarlinPST13 scheme.- Verifier
Key VerifierKeyis used to check evaluation proofs for a given commitment.
Type Aliases
- Prepared
Verifier Key - Nothing to do to prepare this verifier key (for now).